@@ -1,10 +1,9 @@
-# coding: utf-8
 """
 Multiprocessing utilities.
 """
 
 from multiprocessing import Pool
-from typing import Iterable, Callable
+from typing import Callable, Iterable
 
 try:
     from tqdm.autonotebook import tqdm
