@@ -1,7 +1,6 @@
 import unittest
-import pickle
 
-from monty.design_patterns import singleton, cached_class
+from monty.design_patterns import cached_class, singleton
 
 
 class SingletonTest(unittest.TestCase):
@@ -17,7 +16,7 @@ class SingletonTest(unittest.TestCase):
 
 
 @cached_class
-class A(object):
+class A:
     def __init__(self, val):
         self.val = val
 
