@@ -1,16 +1,16 @@
-import unittest
-import sys
 import platform
-from io import open
+import sys
 import time
+import unittest
+
 from monty.functools import (
-    lru_cache,
+    TimeoutError,
     lazy_property,
+    lru_cache,
+    prof_main,
     return_if_raise,
     return_none_if_raise,
     timeout,
-    TimeoutError,
-    prof_main,
 )
 
 
@@ -79,10 +79,10 @@ class TestCase(unittest.TestCase):
         except exc_cls as e:
             exc_str = str(e)
         else:
-            self.fail("%s not raised" % (exc_cls.__name__,))
+            self.fail(f"{exc_cls.__name__} not raised")
 
         if pattern not in exc_str:
-            self.fail("%r not in %r" % (pattern, exc_str))
+            self.fail(f"{pattern!r} not in {exc_str!r}")
 
 
 class LazyTests(TestCase):
@@ -90,7 +90,7 @@ class LazyTests(TestCase):
         # Lazy attributes should be evaluated when accessed.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -104,7 +104,7 @@ class LazyTests(TestCase):
         # lazy_property attributes should be evaluated only once.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -121,7 +121,7 @@ class LazyTests(TestCase):
         # lazy_property attributes.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def __foo(self):
                 called.append("foo")
@@ -140,7 +140,7 @@ class LazyTests(TestCase):
         # It should be possible to create reserved lazy_property attributes.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def __foo__(self):
                 called.append("foo")
@@ -157,7 +157,7 @@ class LazyTests(TestCase):
         # the object __dict__, shadowing the descriptor.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -187,7 +187,7 @@ class LazyTests(TestCase):
         # used on a read-only object (an object with __slots__).
         called = []
 
-        class Foo(object):
+        class Foo:
             __slots__ = ()
 
             @lazy_property
@@ -212,7 +212,7 @@ class LazyTests(TestCase):
     def test_introspection(self):
         # The lazy_property decorator should support basic introspection.
 
-        class Foo(object):
+        class Foo:
             def foo(self):
                 """foo func doc"""
 
@@ -234,7 +234,7 @@ class InvalidateTests(TestCase):
         # It should be possible to invalidate a lazy_property attribute.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -254,7 +254,7 @@ class InvalidateTests(TestCase):
         # twice without causing harm.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -275,7 +275,7 @@ class InvalidateTests(TestCase):
         # cache without causing harm.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -289,7 +289,7 @@ class InvalidateTests(TestCase):
         # It should be possible to invalidate a private lazy_property attribute.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def __foo(self):
                 called.append("foo")
@@ -312,7 +312,7 @@ class InvalidateTests(TestCase):
         # by its mangled name.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def __foo(self):
                 called.append("foo")
@@ -334,7 +334,7 @@ class InvalidateTests(TestCase):
         # It should be possible to invalidate a reserved lazy_property attribute.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def __foo__(self):
                 called.append("foo")
@@ -354,7 +354,7 @@ class InvalidateTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Foo(object):
+        class Foo:
             def foo(self):
                 called.append("foo")
                 return 1
@@ -373,7 +373,7 @@ class InvalidateTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Foo(object):
+        class Foo:
             def __foo(self):
                 called.append("foo")
                 return 1
@@ -392,7 +392,7 @@ class InvalidateTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Foo(object):
+        class Foo:
             @lazy_property
             def foo(self):
                 called.append("foo")
@@ -412,7 +412,7 @@ class InvalidateTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Foo(object):
+        class Foo:
             __slots__ = ()
 
             @lazy_property
@@ -440,7 +440,7 @@ class InvalidateSubclassTests(TestCase):
         # It should be possible to invalidate a cached attribute.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def bar(self):
                 called.append("bar")
@@ -460,7 +460,7 @@ class InvalidateSubclassTests(TestCase):
         # twice without causing harm.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def bar(self):
                 called.append("bar")
@@ -481,7 +481,7 @@ class InvalidateSubclassTests(TestCase):
         # cache without causing harm.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def bar(self):
                 called.append("bar")
@@ -495,7 +495,7 @@ class InvalidateSubclassTests(TestCase):
         # It should be possible to invalidate a private cached attribute.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def __bar(self):
                 called.append("bar")
@@ -518,7 +518,7 @@ class InvalidateSubclassTests(TestCase):
         # by its mangled name.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def __bar(self):
                 called.append("bar")
@@ -540,7 +540,7 @@ class InvalidateSubclassTests(TestCase):
         # It should be possible to invalidate a reserved cached attribute.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def __bar__(self):
                 called.append("bar")
@@ -560,7 +560,7 @@ class InvalidateSubclassTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Bar(object):
+        class Bar:
             def bar(self):
                 called.append("bar")
                 return 1
@@ -579,7 +579,7 @@ class InvalidateSubclassTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Bar(object):
+        class Bar:
             def __bar(self):
                 called.append("bar")
                 return 1
@@ -598,7 +598,7 @@ class InvalidateSubclassTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def bar(self):
                 called.append("bar")
@@ -618,7 +618,7 @@ class InvalidateSubclassTests(TestCase):
         # raise an AttributeError.
         called = []
 
-        class Bar(object):
+        class Bar:
             __slots__ = ()
 
             @cached
@@ -639,7 +639,7 @@ class InvalidateSubclassTests(TestCase):
         # cached.invalidate CANNOT invalidate a superclass (lazy_property) attribute.
         called = []
 
-        class Bar(object):
+        class Bar:
             @lazy_property
             def bar(self):
                 called.append("bar")
@@ -658,7 +658,7 @@ class InvalidateSubclassTests(TestCase):
         # Whereas lazy_property.invalidate CAN invalidate a subclass (cached) attribute.
         called = []
 
-        class Bar(object):
+        class Bar:
             @cached
             def bar(self):
                 called.append("bar")
@@ -715,7 +715,7 @@ class AssertExceptionTests(TestCase):
 
 class TryOrReturnTest(unittest.TestCase):
     def test_decorator(self):
-        class A(object):
+        class A:
             @return_if_raise(ValueError, "hello")
             def return_one(self):
                 return 1
