@@ -1,10 +1,9 @@
-# coding: utf-8
 import unittest
 
-from monty.inspect import *
+from monty.inspect import all_subclasses, caller_name, find_top_pyfile
 
 
-class LittleCatA(object):
+class LittleCatA:
     pass
 
 
@@ -12,7 +11,7 @@ class LittleCatB(LittleCatA):
     pass
 
 
-class LittleCatC(object):
+class LittleCatC:
     pass
 
 
