@@ -1,8 +1,10 @@
-__version__ = "0.1"
+from __future__ import annotations
 
+import dataclasses
 import datetime
 import json
 import os
+import pathlib
 import unittest
 from enum import Enum
 
@@ -107,6 +109,25 @@ class ClassContainingNumpyArray(MSONable):
         self.np_a = np_a
 
 
+@dataclasses.dataclass
+class Point:
+    x: float = 1
+    y: float = 2
+
+
+class Coordinates(MSONable):
+    def __init__(self, points):
+        self.points = points
+
+    def __str__(self):
+        return str(self.points)
+
+
+@dataclasses.dataclass
+class NestedDataClass:
+    points: list[Point]
+
+
 class MSONableTest(unittest.TestCase):
     def setUp(self):
         self.good_cls = GoodMSONClass
@@ -511,6 +532,10 @@ class JsonTest(unittest.TestCase):
         self.assertEqual(clean["a"], bytes(rnd_bin))
         self.assertIsInstance(clean["a"], bytes)
 
+        p = pathlib.Path("/home/user/")
+        clean = jsanitize(p, strict=True)
+        self.assertIn(clean, ["/home/user", "\\home\\user"])
+
         # test jsanitizing callables (including classes)
         instance = MethodSerializationClass(a=1)
         for function in [
@@ -647,6 +672,26 @@ class JsonTest(unittest.TestCase):
         assert isinstance(obj.a, GoodMSONClass)
         assert obj.a.b == 1
 
+    def test_dataclass(self):
+
+        c = Coordinates([Point(1, 2), Point(3, 4)])
+        d = c.as_dict()
+        c2 = Coordinates.from_dict(d)
+        self.assertEqual(d["points"][0]["x"], 1)
+        self.assertEqual(d["points"][1]["y"], 4)
+        self.assertIsInstance(c2, Coordinates)
+        self.assertIsInstance(c2.points[0], Point)
+
+        s = MontyEncoder().encode(Point(1, 2))
+        p = MontyDecoder().decode(s)
+        self.assertEqual(p.x, 1)
+        self.assertEqual(p.y, 2)
+
+        ndc = NestedDataClass([Point(1, 2), Point(3, 4)])
+        str_ = json.dumps(ndc, cls=MontyEncoder)
+        ndc2 = json.loads(str_, cls=MontyDecoder)
+        self.assertIsInstance(ndc2, NestedDataClass)
+
 
 if __name__ == "__main__":
     unittest.main()
